<template>
  <div class="app-container">
    <div style="display: flex;justify-content: space-between">
      <el-form :inline="true" style="display: flex;align-items: center;flex-wrap: wrap;" >
        <el-form-item>
          <el-button
              type="primary"
              plain
              icon="Plus"
              @click="openDialog('add',{})"
          >新增</el-button>
        </el-form-item>
        <el-form-item label="姓名：" >
          <el-input v-model="data.queryParams.name" placeholder="请输入姓名"></el-input>
        </el-form-item>
        <el-form-item >
          <el-button
              type="primary"
              @click="getList"
          >查询</el-button>
          <el-button
              type="primary"
              plain
              @click="reset"
          >重置</el-button>
        </el-form-item>
      </el-form>
    </div>
    <!-- 表格数据 -->
    <el-table v-loading="loading" :data="dataList" :border="true">
      <el-table-column label="序号" type="index" align="center" width="80" />
      <el-table-column label="工号" prop="empno" align="center"  />
      <el-table-column label="姓名" prop="name" align="center"  />
      <el-table-column label="性别" prop="sex" align="center" >
        <template #default="scope">
          <span>{{scope.row.sex == 0 ? '男':'女'}}</span>
        </template>
      </el-table-column>
      <el-table-column label="手机号" prop="phone" align="center" width="130"/>
      <el-table-column label="身份证" prop="idNo" align="center" width="200" :show-overflow-tooltip="true"/>
      <el-table-column label="创建人" prop="createBy" align="center">
        <template #default="scope">
          <span>{{scope.row.createUser.name}}</span>
        </template>
      </el-table-column>
      <el-table-column label="工作岗位" prop="post" align="center"/>
      <el-table-column label="职务" prop="duty" align="center"/>
      <el-table-column label="一人一档" prop="duty" align="center" width="120">
        <template #default="scope">
          <el-button link type="primary" @click="openRecord(scope.row)">培训考试记录</el-button>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width"  width="180">
        <template #default="scope">
          <el-button link type="primary" @click="openDialog('edit',scope.row)">编辑</el-button>
          <el-button link type="danger" @click="handleDelete(scope.row)">删除</el-button>
          <el-button link type="primary" @click="openDialog('pwd',scope.row)">修改密码</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
        v-show="total > 0"
        :total="total"
        v-model:page="queryParams.pageNum"
        v-model:limit="queryParams.pageSize"
        @pagination="getList"
    />

    <stu-dialog ref="dialogRef" @getList=getList></stu-dialog>
    <record ref="recordRef" @getList=getList></record>
  </div>
</template>

<script setup>
import {getCurrentInstance, onMounted, onUnmounted, reactive, ref, toRefs} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import {delCompany, getCompany} from "@/api/onlineEducation/company";
import stuDialog from "./components/stuDialog.vue"
import record from './components/trainRecord.vue'
import {delUser, getUser} from "@/api/onlineEducation/user";
import Cookies from "js-cookie";
import {delStudent, getStudent} from "@/api/onlineEducation/student";


const { proxy } = getCurrentInstance();
const loading = ref(false);
const dialogRef = ref();
const recordRef  =ref();
const data = reactive({
  queryParams: {
    pageNum: 1,
    pageSize: 10,
    name: ''
  },
  total: 0,
  dataList: [],
  isAdmin: false

});

const { queryParams, total, dataList } = toRefs(data);
const userType = ref()
onMounted(async ()=>{
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  console.log("userInfo",userInfo)
  userType.value = userInfo.userType
  if(userInfo.userType === 0){
    data.isAdmin = true;
  }else {
    data.isAdmin = false;
  }
  await getList()
})
onUnmounted(()=>{

})

const getList = async () => {
  loading.value = true
  const res = await getStudent(data.queryParams)
  if(res.code == 200){
    data.dataList = res.data.list
    data.total = res.data.total
  }else{
    ElMessage.warning(res.message)
  }
  loading.value = false
}

const openDialog = (type, value) => {
  if(type == 'add' && data.isAdmin){
    ElMessage.warning('监管部门请联系企业创建企业学员')
  }
  // else if(userType.value !== 3 && (type == 'add' || type == 'edit')) {
  //   ElMessage.warning(' 只有车间级用户才能新增和编辑')
  // }
  else{
    dialogRef.value.openDialog(type, value);
  }


}

/** 重置新增的表单以及其他数据  */
function reset() {
  data.queryParams = {
    pageNum: 1,
    pageSize: 10,
    name: ''
  }
  getList()
}
const handleDelete = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delStudent(val.id)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          await getList()
        }else{
          ElMessage.warning(res.message)
        }
      })
}
const openRecord = (val) => {
  recordRef.value.openDialog(val)
}

</script>
